@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2008  NTT DATA CORPORATION
  *
- * Version: 1.6.3   2008/07/15
+ * Version: 1.6.4   2008/09/03
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -189,7 +189,7 @@ static bool is_byte_range(const char *str)
  */
 static bool is_decimal(const char c)
 {
-	return (c >= '0' && c <= '9');
+	return c >= '0' && c <= '9';
 }
 
 /**
@@ -201,9 +201,9 @@ static bool is_decimal(const char c)
  */
 static bool is_hexadecimal(const char c)
 {
-	return ((c >= '0' && c <= '9') ||
+	return (c >= '0' && c <= '9') ||
 		(c >= 'A' && c <= 'F') ||
-		(c >= 'a' && c <= 'f'));
+		(c >= 'a' && c <= 'f');
 }
 
 /**
@@ -215,7 +215,7 @@ static bool is_hexadecimal(const char c)
  */
 static bool is_alphabet_char(const char c)
 {
-	return ((c >= 'A' && c <= 'F') || (c >= 'a' && c <= 'f'));
+	return (c >= 'A' && c <= 'F') || (c >= 'a' && c <= 'f');
 }
 
 /**
@@ -670,7 +670,7 @@ static bool file_matches_to_pattern2(const char *filename,
 	while (*pattern == '\\' &&
 	       (*(pattern + 1) == '*' || *(pattern + 1) == '@'))
 		pattern += 2;
-	return (filename == filename_end && pattern == pattern_end);
+	return filename == filename_end && pattern == pattern_end;
 }
 
 /**
@@ -772,7 +772,7 @@ bool ccs_path_matches_pattern(const struct path_info *filename,
 	while (*p == '\\' &&
 	       (*(p + 1) == '*' || *(p + 1) == '@'))
 		p += 2;
-	return (!*f && !*p);
+	return !*f && !*p;
 }
 
 /**
@@ -2411,10 +2411,10 @@ void ccs_load_policy(const char *filename)
 	}
 #endif
 #ifdef CONFIG_SAKURA
-	printk(KERN_INFO "SAKURA: 1.6.3   2008/07/15\n");
+	printk(KERN_INFO "SAKURA: 1.6.4   2008/09/03\n");
 #endif
 #ifdef CONFIG_TOMOYO
-	printk(KERN_INFO "TOMOYO: 1.6.3   2008/07/15\n");
+	printk(KERN_INFO "TOMOYO: 1.6.4   2008/09/03\n");
 #endif
 	printk(KERN_INFO "Mandatory Access Control activated.\n");
 	sbin_init_started = true;
@@ -2764,7 +2764,7 @@ static int read_updates_counter(struct ccs_io_buffer *head)
 static int read_version(struct ccs_io_buffer *head)
 {
 	if (!head->read_eof) {
-		ccs_io_printf(head, "1.6.3");
+		ccs_io_printf(head, "1.6.4");
 		head->read_eof = true;
 	}
 	return 0;
