@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2008  NTT DATA CORPORATION
  *
- * Version: 1.6.3   2008/07/15
+ * Version: 1.6.4   2008/09/03
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -105,24 +105,30 @@ static int print_error(const char *root_name, const u8 mode)
 	return error;
 }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 27)
+#define PATH_or_NAMEIDATA path
+#else
+#define PATH_or_NAMEIDATA nameidata
+#endif
 /**
  * ccs_check_chroot_permission - Check permission for chroot().
  *
- * @nd: Pointer to "struct nameidata".
+ * @path: Pointer to "struct path" (for 2.6.27 and later).
+ *        Pointer to "struct nameidata" (for 2.6.26 and earlier).
  *
  * Returns 0 on success, negative value otherwise.
  */
-int ccs_check_chroot_permission(struct nameidata *nd)
+int ccs_check_chroot_permission(struct PATH_or_NAMEIDATA *path)
 {
 	int error = -EPERM;
 	char *root_name;
 	const u8 mode = ccs_check_flags(CCS_SAKURA_RESTRICT_CHROOT);
 	if (!mode)
 		return 0;
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 25)
-	root_name = ccs_realpath_from_dentry(nd->path.dentry, nd->path.mnt);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 25) && LINUX_VERSION_CODE <= KERNEL_VERSION(2, 6, 26)
+	root_name = ccs_realpath_from_dentry(path->path.dentry, path->path.mnt);
 #else
-	root_name = ccs_realpath_from_dentry(nd->dentry, nd->mnt);
+	root_name = ccs_realpath_from_dentry(path->dentry, path->mnt);
 #endif
 	if (root_name) {
 		struct path_info dir;
