@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2008  NTT DATA CORPORATION
  *
- * Version: 1.6.3   2008/07/15
+ * Version: 1.6.4   2008/09/03
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -1316,10 +1316,7 @@ static inline int root_depth(struct dentry *dentry, struct vfsmount *vfsmnt)
 {
 	int depth = 0;
 	/***** CRITICAL SECTION START *****/
-	spin_lock(&dcache_lock);
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 0)
-	spin_lock(&vfsmount_lock);
-#endif
+	ccs_realpath_lock();
 	for (;;) {
 		if (dentry == vfsmnt->mnt_root || IS_ROOT(dentry)) {
 			/* Global root? */
@@ -1332,10 +1329,7 @@ static inline int root_depth(struct dentry *dentry, struct vfsmount *vfsmnt)
 		dentry = dentry->d_parent;
 		depth++;
 	}
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 5, 0)
-	spin_unlock(&vfsmount_lock);
-#endif
-	spin_unlock(&dcache_lock);
+	ccs_realpath_unlock();
 	/***** CRITICAL SECTION END *****/
 	return depth;
 }
