@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2008  NTT DATA CORPORATION
  *
- * Version: 1.6.2   2008/06/25
+ * Version: 1.6.4   2008/09/03
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -65,7 +65,8 @@ static const struct in6_addr *save_ipv6_address(const struct in6_addr *addr)
 {
 	static const u8 block_size = 16;
 	struct addr_list {
-		struct in6_addr addr[block_size];
+		/* Workaround for gcc 4.3's bug. */
+		struct in6_addr addr[16]; /* = block_size */
 		struct list1_head list;
 		u32 in_use_count;
 	};
